@@ -31,6 +31,7 @@
 #include "interface.h"
 #include "iterator.h"
 #include "message.h"
+#include "object.h"
 #include "pad.h"
 #include "padtemplate.h"
 #include "parse.h"
@@ -60,6 +61,7 @@
 #include "baseaudiosink.h"
 #include "baseaudiosrc.h"
 #include "cddabasesrc.h"
+#include "ringbuffer.h"
 #include "videosink.h"
 #include "colorbalance.h"
 #include "colorbalancechannel.h"
