@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "glibmm_generate_extra_defs/generate_extra_defs.h"
+#include <glibmm_generate_extra_defs/generate_extra_defs.h>
 #include "get_plugin_defs.h"
 
 // Core includes
@@ -195,6 +195,9 @@ int main (int argc, char *argv[])
             << get_plugin_defs("oggmux")
             << get_plugin_defs("playbin")
             << get_plugin_defs("playbin2")
+            << get_plugin_defs("tcpclientsrc")
+            << get_plugin_defs("tcpclientsink")
+            << get_plugin_defs("tcpserversrc")
             << get_plugin_defs("tcpserversink")
             << get_plugin_defs("textoverlay")
             << get_plugin_defs("textrender")
